@@ -94,6 +94,7 @@ static std::string arguments()
 	output <<
 		"Input engine parameters:\n"
 		"  jackmidi:  midimap=<midimapfile>\n"
+		"  alsamidi:  midimap=<midimapfile>\n"
 		"  midifile:  file=<midifile>, speed=<tempo> (default 1.0),\n"
 		"             track=<miditrack> (default -1, all tracks)\n"
 		"             midimap=<midimapfile>, loop=<true|false>\n"
@@ -105,7 +106,8 @@ static std::string arguments()
 		"\n"
 		"Output engine parameters:\n"
 		"  alsa:      dev=<device> (default 'default'), frames=<frames> (default "
-		"32)\n"
+		"32),\n"
+		"             periods=<periods> (default 3)\n"
 		"             srate=<samplerate> (default 441000)\n"
 		"  oss:       dev=<device> (default '/dev/dsp'), srate=<samplerate>,\n"
 		"             max_fragments=<number> (default 4, see man page for more info),\n"
@@ -140,6 +142,12 @@ static std::string arguments()
 		"  diverse:       The importance given to choosing samples\n"
 		"                 which haven't been played recently. [0,1]\n"
 		"  random:        The amount of randomness added. [0,1]\n"
+		"\n"
+		"Voice limit parameters:\n"
+		"  max:           Maximum number of voices for each instrument before\n"
+		"                 old samples are ramped down. [1,30]\n"
+		"  rampdown:      Time it takes for an old sample to completely fall\n"
+		"                 silent. [0.01,2.0]\n"
 		"\n";
 	return output.str();
 }
@@ -261,7 +269,7 @@ int main(int argc, char* argv[])
 	        });
 
 	opt.add("inputengine", required_argument, 'i',
-	        "dummy|test|jackmidi|midifile  Use said event input engine.",
+	        "dummy|test|jackmidi|alsamidi|midifile  Use said event input engine.",
 	        [&]()
 	        {
 		        std::string engine = optarg;
@@ -324,6 +332,7 @@ int main(int argc, char* argv[])
 		        }
 		        oe = factory.createOutput(engine);
 		        if(ie == NULL)
+		        if(oe == NULL)
 		        {
 			        std::cerr << "Invalid output engine: " << engine << std::endl;
 			        return 1;
@@ -542,6 +551,54 @@ int main(int argc, char* argv[])
 		        return 0;
 	        });
 
+	// Default is to disable voice limit
+	settings.enable_voice_limit.store(false);
+
+	opt.add("voice-limit", no_argument, 'l',
+	        "Enable voice limit.",
+	        [&]()
+	        {
+		        settings.enable_voice_limit.store(true);
+		        return 0;
+	        });
+
+	opt.add("voice-limitparms", required_argument, 'L',
+	        "Voice limit options.",
+	        [&]()
+	        {
+		        std::string parms = optarg;
+		        auto tokens = parseParameters(parms);
+		        for(auto& token : tokens)
+		        {
+			        if(token.key == "max")
+			        {
+				        auto val = atof_nol(token.value.data());
+				        if(val < 1.0 || val > 30.0)
+				        {
+					        std::cerr << "max range is [1, 30].\n";
+					        return 1;
+				        }
+				        settings.voice_limit_max.store(val);
+			        }
+			        else if(token.key == "rampdown")
+			        {
+				        auto val = atof_nol(token.value.data());
+				        if(val < 0.01 || val > 2.0)
+				        {
+					        std::cerr << "rampdown range is [0.01, 2.0].\n";
+					        return 1;
+				        }
+				        settings.voice_limit_rampdown.store(val);
+			        }
+			        else
+			        {
+				        std::cerr << "Unknown voice limitparms argument " << token.key << std::endl;
+				        return 1;
+			        }
+		        }
+		        return 0;
+	        });
+
 	opt.add("parameters", required_argument, 'p',
 	        "Parameters for sample selection algorithm.",
 	        [&]()
@@ -698,6 +755,34 @@ int main(int argc, char* argv[])
 		}
 		std::cout << "\ndone" << std::endl;
 	}
+	else
+	{
+		// Async loading in progress
+
+		// Wait until the loader has passed the kit parsing step before proceeding.
+		bool parsing_done{false};
+		while(!parsing_done)
+		{
+			std::this_thread::sleep_for(std::chrono::milliseconds(10));
+
+			switch(settings.drumkit_load_status.load())
+			{
+			case LoadStatus::Idle:
+			case LoadStatus::Parsing:
+				// Not yet past the parsing step
+				break;
+			case LoadStatus::Loading:
+			case LoadStatus::Done:
+				// Past parsing step
+				parsing_done = true;
+				break;
+			case LoadStatus::Error:
+				// Kit parser error?
+				std::cout << "\nFailed to load " << kitfile << std::endl;
+				return 1;
+			}
+		}
+	}
 
 	gizmo.setSamplerate(oe->getSamplerate());
 	oe->onLatencyChange(gizmo.getLatency());
