@@ -66,7 +66,7 @@ void PluginVST::updateLatency()
 {
 	if(update_latency != current_latency)
 	{
-		AudioEffectX::setInitialDelay(current_latency);
+		AudioEffectX::setInitialDelay(update_latency);
 		AudioEffectX::ioChanged();
 		current_latency = update_latency;
 	}
@@ -296,6 +296,8 @@ VstInt32 PluginVST::processEvents(VstEvents* events)
 void PluginVST::processReplacing(float** inputs, float** outputs,
                                  VstInt32 sampleFrames)
 {
+	updateLatency();
+
 	// Process 32 bit (single precision) floats (always in a resume state).
 
 	// 0 = realtime/normal
