@@ -28,9 +28,10 @@
 
 #include <sndfile.h>
 
-Sample::Sample(const std::string& name, float power)
+Sample::Sample(const std::string& name, double power, bool normalized)
 	: name{name}
 	, power{power}
+	, normalized(normalized)
 	, audiofiles{}
 {
 }
@@ -39,12 +40,12 @@ Sample::~Sample()
 {
 }
 
-void Sample::addAudioFile(Channel* c, AudioFile* a)
+void Sample::addAudioFile(InstrumentChannel* c, AudioFile* a)
 {
 	audiofiles[c] = a;
 }
 
-AudioFile* Sample::getAudioFile(Channel* c)
+AudioFile* Sample::getAudioFile(const Channel& channel) const
 {
 	/*
 	if(audiofiles.find(c) == audiofiles.end()) return nullptr;
@@ -54,7 +55,7 @@ AudioFile* Sample::getAudioFile(Channel* c)
 	// todo: std::find_if ??
 	for (auto& pair: audiofiles)
 	{
-		if (pair.first->num == c->num)
+		if (pair.first->num == channel.num)
 		{
 			return pair.second;
 		}
@@ -62,3 +63,13 @@ AudioFile* Sample::getAudioFile(Channel* c)
 
 	return nullptr;
 }
+
+double Sample::getPower() const
+{
+	return power;
+}
+
+bool Sample::getNormalized() const
+{
+	return normalized;
+}
