@@ -26,16 +26,16 @@
  */
 #include <uunit.h>
 
-#include "../plugingui/resource.h"
+#include "../dggui/resource.h"
 
 #include "drumkit_creator.h"
 
 class ResourceTester
-	: public GUI::Resource
+	: public dggui::Resource
 {
 public:
 	ResourceTester(const std::string& name)
-		: GUI::Resource(name)
+		: dggui::Resource(name)
 	{}
 
 	bool probeIsInternal()
